@@ -14,7 +14,9 @@ class TrivialFmtStringTransformer(NoqaAwareTransformer):
             # will fail SimpleString's internal validation. This is due to
             # SimpleString._get_prefix treating everything before quotation
             # marks as a prefix. (sic!)
-            return cst.SimpleString(value=f'"{updated_node.parts[0].value}"')
+            return cst.SimpleString(
+                value=f'{updated_node.start.replace("f", "")}{updated_node.parts[0].value}{updated_node.end}'
+            )
 
         return original_node
 
